@@ -43,12 +43,21 @@ class Processor(object):
         except IndexError:
             self.application.ioloop.add_timeout(self.application.interval, self.application.next)
         else:
+            print "new_task", task
+
             if hasattr(task, "__call__"):
                 task()
                 self.application.ioloop.add_timeout(self.application.interval, self.next)
             else:
-                self.process = subprocess.Popen(task)
-                self.application.ioloop.add_timeout(self.application.interval, self.wait)
+                try:
+                    self.process = subprocess.Popen(task, shell=True)
+                except OSError, ex:
+                    self.error(ex)
+                else:
+                    self.application.ioloop.add_timeout(self.application.interval, self.wait)
+
+    def error(self, ex):
+        self.application.ioloop.add_timeout(self.application.interval, self.application.next)
 
     def wait(self):
         return_code = self.process.returncode
@@ -58,8 +67,7 @@ class Processor(object):
         elif return_code == 0:
             self.application.ioloop.add_timeout(self.application.interval, self.next)
         else:
-            #TODO: mark bad build
-            self.application.ioloop.add_timeout(self.application.interval, self.application.next)
+            self.error(return_code)
 
 
 class Application(tornado.web.Application):
